@@ -43,6 +43,8 @@ class Routing(object):
         self.waypoints = points
         self.points = self._get_points_in_lines(self.waypoints)
         self.routes = self._points_route()
+        self.full_waypoints = [{"coordinates": point.coords, }
+                               for point in points]
 
     def get_route(self):
         """ Return the geometry of the route from the given points """
@@ -68,7 +70,7 @@ class Routing(object):
                 first_point_on_way = Point(way.coords[0])
                 last_point_on_way = Point(way.coords[-1])
             else:
-                return way
+                return 0, 0, way
 
             # find closest point for start_point
             if start_point.distance(first_point_on_way) <= start_point.distance(last_point_on_way):
@@ -79,15 +81,20 @@ class Routing(object):
                 last_point = first_point_on_way
 
             # add first and final segments
-            segment_1 = LineString(start_point, first_point)
-            segment_2 = LineString(end_point, last_point)
+            segment_1 = LineString(start_point, first_point, srid=app_settings.INTERNAL_GEOMETRY_SRID)
+            segment_2 = LineString(end_point, last_point, srid=app_settings.INTERNAL_GEOMETRY_SRID)
+
             if way.geom_type == "MultiLineString":
                 way_linestrings = [line for line in way]
                 final_way = MultiLineString(*way_linestrings, *[segment_1, segment_2])
             else:
                 final_way = MultiLineString(*[way, segment_1, segment_2])
             final_way.simplify(tolerance=app_settings.GEOSTORE_ROUTING_TOLERANCE, preserve_topology=True)
-            return final_way.merged
+            raw_query_length = "SELECT ST_Length(%s::geography), ST_Length(%s::geography);"
+            cursor = connection.cursor()
+            cursor.execute(raw_query_length, [segment_1.wkt, segment_2.wkt])
+            distance_start, distance_end = cursor.fetchall()[0]
+            return round(distance_start, 2), round(distance_end, 2), final_way.merged
 
     @classmethod
     def update_topology(cls, layer, features=None, tolerance=app_settings.GEOSTORE_ROUTING_TOLERANCE, clean=False):
