@@ -2,8 +2,9 @@ from django.urls import reverse
 from rest_framework import serializers
 
 
-class RoutingLayerSerializer:
+class RoutingLayerSerializerMixin(serializers.Serializer):
     routing_url = serializers.SerializerMethodField()
 
     def get_routing_url(self, obj):
-        return reverse('layer-route', args=[obj.pk, ])
+        if obj.routable:
+            return reverse('layer-route', args=[obj.pk, ])
